/*
 * item_respawn_task.hpp
 *
 * This file is part of Knights.
 *
 * Copyright (C) Stephen Thompson, 2006 - 2010.
 * Copyright (C) Kalle Marjola, 1994.
 *
 * Knights is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Knights is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Knights.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*
 * Task that respawns items randomly after the game has been running for a while.
 *
 * Note that one important function of the item respawning is to put down extra
 * lockpicks. If all keys and lockpicks were placed behind locked doors, then
 * this will (eventually) place extra lockpicks somewhere where the players
 * can reach them.
 *
 */

#ifndef ITEM_RESPAWN_TASK_HPP
#define ITEM_RESPAWN_TASK_HPP

#include "task.hpp"

class ItemGenerator;
class ItemType;

class ItemRespawnTask : public Task
{
public:
    ItemRespawnTask(const ItemGenerator *item_gen_,
                    const ItemType *lockpicks_,
                    int interval_,
                    int time_base_,
                    int odds_);

    virtual void execute(TaskManager &tm);

private:
    int countLockpicks() const;
    
    const ItemGenerator *item_gen;
    const ItemType *lockpicks;
    int interval;
    int time_base;
    int odds;
};

#endif
